@@ -23,7 +23,6 @@
 """
 from __future__ import annotations
 
-import argparse
 import logging
 import math
 import operator
@@ -83,6 +82,8 @@ CELERY_SEND_ERR_MSG_HEADER = "Error sending Celery task"
 
 
 if TYPE_CHECKING:
+    import argparse
+
     from celery import Task
 
     from airflow.executors.base_executor import CommandType, TaskTuple
@@ -367,9 +368,7 @@ class CeleryExecutor(BaseExecutor):
                 self.success(key, info)
             elif state in (celery_states.FAILURE, celery_states.REVOKED):
                 self.fail(key, info)
-            elif state == celery_states.STARTED:
-                pass
-            elif state == celery_states.PENDING:
+            elif state in (celery_states.STARTED, celery_states.PENDING):
                 pass
             else:
                 self.log.info("Unexpected state for %s: %s", key, state)
